@@ -37,16 +37,6 @@ localedir = os.path.join ("/export/home/wwalker/work/orca/bld", "share", "locale
 gettext.bindtextdomain ("orca", localedir)
 gettext.textdomain("orca")
 
-import debug
-
-try:
-    import gtk.glade
-
-    gtk.glade.bindtextdomain ("orca", localedir)
-    gtk.glade.textdomain("orca")
-except:
-    debug.printException(debug.LEVEL_FINEST)
-
 ########################################################################
 #                                                                      #
 # Utility methods to facilitate easier translation                     #
