@@ -28,7 +28,7 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "2.27.3"
+version     = "2.27.5"
 
 # "--prefix" parameter used when configuring the build.
 #
@@ -41,3 +41,7 @@ package     = "orca"
 # The name of the data directory (usually "share").
 #
 datadirname = "share"
+
+# The directory where we could find liblouis translation tables.
+#
+tablesdir = "/usr/share/liblouis/tables"
