@@ -100,8 +100,8 @@ class Script(default.Script):
                pageTab.getRole() == pyatspi.ROLE_PAGE_TAB and \
                pageTab.getState().contains(pyatspi.STATE_SENSITIVE):
                 self.updateBraille(newLocusOfFocus)
-                utterances = self.speechGenerator.getSpeech(pageTab, False)
-                speech.speakUtterances(utterances)
+                utterances = self.speechGenerator.generateSpeech(pageTab)
+                speech.speak(utterances)
 
         default.Script.locusOfFocusChanged(self, event, 
                                            oldLocusOfFocus, newLocusOfFocus)
@@ -256,7 +256,21 @@ class Script(default.Script):
             speakThis = True
 
         if matchFound:
-            orca.keyEcho(orca_state.lastInputEvent)
+            echoed = orca.keyEcho(orca_state.lastInputEvent)
+        else:
+            echoed = False
+
+        if not echoed:
+            # We might need to echo this if it is a single character.
+            #
+            speakThis = speakThis \
+                or ((settings.enableEchoByCharacter \
+                     or (settings.enableKeyEcho \
+                         and settings.enablePrintableKeys)) \
+                    and text \
+                    and event.source.getRole() \
+                        != pyatspi.ROLE_PASSWORD_TEXT \
+                    and len(text.decode("UTF-8")) == 1)
 
         if speakThis:
             if text.isupper():
