@@ -51,11 +51,11 @@ import orca.settings as settings
 import orca.keybindings as keybindings
 
 from orca.orca_i18n import _ # for gettext support
-from orca.structural_navigation import StructuralNavigation
 
 from speech_generator import SpeechGenerator
 from braille_generator import BrailleGenerator
 from formatting import Formatting
+from structural_navigation import StructuralNavigation
 import script_settings
 
 class Script(default.Script):
@@ -200,6 +200,12 @@ class Script(default.Script):
         """Returns the formatting strings for this script."""
         return Formatting(self)
 
+    def getStructuralNavigation(self):
+        """Returns the 'structural navigation' class for this script.
+        """
+        types = self.getEnabledStructuralNavigationTypes()
+        return StructuralNavigation(self, types, enabled=False)
+
     def getEnabledStructuralNavigationTypes(self):
         """Returns a list of the structural navigation object types
         enabled in this script.
@@ -1501,7 +1507,7 @@ class Script(default.Script):
                 textToSpeak = result[0].decode("UTF-8")
                 self._speakWriterText(event, textToSpeak)
                 braille.displayRegions(\
-                    brailleGen.getBrailleRegions(event.source))
+                    brailleGen.generateBraille(event.source))
                 return
 
         # Check to see if the object that just got focus is in the Setup
@@ -2256,7 +2262,7 @@ class Script(default.Script):
             textToSpeak = result.decode("UTF-8")
             self._speakWriterText(event, textToSpeak)
             braille.displayRegions( \
-                self.brailleGenerator.getBrailleRegions(event.source))
+                self.brailleGenerator.generateBraille(event.source))
         else:
             default.Script.onCaretMoved(self, event)
 
