@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2008 Sun Microsystems Inc.
+# Copyright 2004-2009 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -24,7 +24,7 @@ case of gdm) or doesn't have the specified attribute."""
 __id__        = "$Id$"
 __version__   = "$Revision$"
 __date__      = "$Date$"
-__copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
+__copyright__ = "Copyright (c) 2004-2009 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 import os
@@ -54,12 +54,6 @@ try:
     screenWidth = _screen.get_width()
     screenHeight = _screen.get_height()
 
-    # We want to know what the tty is so we can send it to BrlAPI
-    # if possible.
-    #
-    (atom, format, data) = _root_window.property_get("XFree86_VT")
-    tty = data[0]
-
     # The bug that caused gnome-panel to crash is fixed in GTK 2.10.11.
     minimum_gtk_version = (100000 * 2) + \
                           (1000 * 10) + \
@@ -68,6 +62,12 @@ try:
                            (1000 * gtk.gtk_version[1]) + \
                             gtk.gtk_version[2]
     canPresentToolTips = (current_gtk_version >= minimum_gtk_version)
+
+    # We want to know what the tty is so we can send it to BrlAPI
+    # if possible.
+    #
+    (atom, format, data) = _root_window.property_get("XFree86_VT")
+    tty = data[0]
 except:
     pass
 
@@ -95,6 +95,7 @@ userCustomizableSettings = [
     "speechVerbosityLevel",
     "readTableCellRow",
     "enableSpeechIndentation",
+    "enableEchoByCharacter",
     "enableEchoByWord",
     "enableEchoBySentence",
     "enableKeyEcho",
@@ -104,8 +105,11 @@ userCustomizableSettings = [
     "enableFunctionKeys",
     "enableActionKeys",
     "enableNavigationKeys",
+    "enableDiacriticalKeys",
+    "enablePauseBreaks",
     "enableTutorialMessages",
     "enableMnemonicSpeaking",
+    "enablePositionSpeaking",
     "enableBraille",
     "enableBrailleContext",
     "enableBrailleGrouping",
@@ -240,6 +244,13 @@ BRAILLE_ROLENAME_STYLE_SHORT = 0 # three letter abbreviations
 BRAILLE_ROLENAME_STYLE_LONG  = 1 # full rolename
 brailleRolenameStyle    = BRAILLE_ROLENAME_STYLE_LONG
 
+# Roles to force to be displayed even when the verbosity level
+# is not verbose.
+#
+brailleForceRoles = [pyatspi.ROLE_COMBO_BOX,
+                     pyatspi.ROLE_MENU,
+                     pyatspi.ROLE_TEAROFF_MENU_ITEM]
+
 # Braille Selection Indicator (see brailleSelectorIndicator).
 # The values represent the character to be used in the attrOr
 # field of brlAPI's writeStruct.
@@ -303,7 +314,7 @@ if os.getenv("DBUS_SESSION_BUS_ADDRESS"):
 else:
     useDBus = False
 
-# Whether or not recording is enabled via the HTTP server. 
+# Whether or not recording is enabled via the HTTP server.
 #
 enableRemoteLogging     = False
 
@@ -341,7 +352,7 @@ enableSpeechIndentation = False
 
 # If True, enable braille.
 #
-enableBraille           = True
+enableBraille           = False
 
 # If True, add the hierarchical context of an object to the braille
 # line.  People with very large braille displays may want to set this
@@ -359,16 +370,6 @@ enableBrailleGrouping   = False
 #
 enableBrailleMonitor    = False
 
-# string to indicate end of printed line for braille displays:
-#
-disableBrailleEOL = False
-brailleEOLIndicator = " $l"
-
-# Strings used to indicate checkbox/radio button states in braille:
-#
-brailleCheckBoxIndicators = ["< >", "<x>", "<->"]
-brailleRadioButtonIndicators = ["& y", "&=y"]
-
 # If True, enable magnification.
 #
 enableMagnifier                  = False
@@ -534,6 +535,12 @@ magSourceDisplay                 = ''
 #
 magTargetDisplay                 = ''
 
+# if True, enable character echo.
+# Note that it is allowable for both enableEchoByCharacter and enableKeyEcho
+# to be True
+#
+enableEchoByCharacter   = False
+
 # if True, enable word echo.
 # Note that it is allowable for both enableEchoByWord and enableKeyEcho
 # to be True
@@ -576,6 +583,10 @@ enableActionKeys        = True
 #
 enableNavigationKeys    = False
 
+# If True and key echo is enabled, echo Diacritical keys.
+#
+enableDiacriticalKeys   = False
+
 # If True, tutorial strings defined will be spoken.
 #
 enableTutorialMessages = False
@@ -584,6 +595,10 @@ enableTutorialMessages = False
 #
 enableMnemonicSpeaking = False
 
+# If true, position indexes  will be spoken automaticaly
+#
+enablePositionSpeaking = False
+
 # If True, show the main Orca window.
 #
 showMainWindow          = True
@@ -609,7 +624,7 @@ keyboardLayout                  = GENERAL_KEYBOARD_LAYOUT_DESKTOP
 #
 outlineColor = [ 0xFFFF, 0x0000, 0x0000 ]
 
-# Thickness in pixels of the outline around the the current item in flat 
+# Thickness in pixels of the outline around the the current item in flat
 # review mode.
 #
 outlineThickness = 4
@@ -653,17 +668,6 @@ progressBarUpdateInterval = 10
 #
 presentReadOnlyText = True
 
-# Translators: this is used to indicate the user is in a text
-# area that is not editable.  It is meant to be spoken to the user.
-#
-speechReadOnlyString = C_("text", "read only")
-
-# Translators: this is used to indicate the user is in a text
-# area that is not editable.  It is meant to be a short abbreviation
-# to be presented on the braille display.
-#
-brailleReadOnlyString = C_("text", "rdonly")
-
 # The complete list of possible text attributes.
 #
 allTextAttributes = \
@@ -875,7 +879,7 @@ def setAccessibilityEnabled(enable):
     except:
         return False
 
-# Obtain/set information regarding whether Orca is autostarted for this 
+# Obtain/set information regarding whether Orca is autostarted for this
 # user at login time.
 #
 def isOrcaAutostarted():
@@ -943,7 +947,7 @@ settingsPackages          = ["app-settings"]
 # REMEMBER: to make something a package, the directory has to
 # have a __init__.py file in it.
 #
-scriptPackages          = ["orca-scripts", "scripts", 
+scriptPackages          = ["orca-scripts", "scripts",
                            "scripts.apps", "scripts.toolkits"]
 
 # A list that helps us map application names to script module
@@ -1092,7 +1096,7 @@ setScriptMapping(re.compile('gnome-help'), "yelp")
 #
 deprecatedMessages = False
 
-# Focus history length. We keep a reference to past focused accessibles to 
+# Focus history length. We keep a reference to past focused accessibles to
 # maximize on caching.
 #
 focusHistoryLength = 5
@@ -1106,22 +1110,22 @@ listenAllEvents = False
 #
 ignoredEventsList = ['object:bounds-changed']
 
-# Listen to Live Region events.  Tells Gecko.onChildrenChanged() and 
+# Listen to Live Region events.  Tells Gecko.onChildrenChanged() and
 # onTextInserted() event handlers to monitor these events for live region
-# changes.  
+# changes.
 #
 inferLiveRegions = True
 
 # Contracted braille support.
-# 
+#
 enableContractedBraille = False
 
 # Contracted braille table.
-# 
+#
 brailleContractionTable = ''
 
 # Use Collection Interface?
-# 
+#
 useCollection = True
 
 # Whether or not to speak the cell's coordinates when navigating
@@ -1156,13 +1160,13 @@ wrappedStructuralNavigation = True
 #
 enableMouseReview = False
 
-# Mouse dwell delay in milliseconds for mouse review mode. 
+# Mouse dwell delay in milliseconds for mouse review mode.
 # If the value is zero, the review will be read time.
 #
 mouseDwellDelay = 0
 
 # Maximum allowed drift while pointer is dwelling in mouse review mode.
-# 
+#
 mouseDwellMaxDrift = 3
 
 # The different modifiers/modifier masks associated with keybindings
@@ -1214,13 +1218,27 @@ defaultModifierMask = NON_LOCKING_MODIFIER_MASK
 #
 presentRequiredState = False
 
-# Translators: Certain objects (such as form controls on web pages)
-# can have STATE_REQUIRED set on them to inform the user that this
-# field must be filled out. This string is the default string which
-# will be spoken and displayed in braille to indicate this state is
-# present.
+########################################################################
+#                                                                      #
+# Sounds                                                               #
+#                                                                      #
+########################################################################
+
+# A dictionary where the keys are rolenames and the values are
+# filenames containing audio snippets.
 #
-brailleRequiredStateString = _("required")
+sounds = {}
+
+########################################################################
+#                                                                      #
+# Strings for speech and braille                                       #
+#                                                                      #
+########################################################################
+
+# Translators: "blank" is a short word to mean the
+# user has navigated to an empty line.
+#
+speechBlankString = _("blank")
 
 # Translators: Certain objects (such as form controls on web pages)
 # can have STATE_REQUIRED set on them to inform the user that this
@@ -1229,3 +1247,123 @@ brailleRequiredStateString = _("required")
 # present.
 #
 speechRequiredStateString = _("required")
+
+# Translators: this is used to indicate the user is in a text
+# area that is not editable.  It is meant to be spoken to the user.
+#
+speechReadOnlyString = C_("text", "read only")
+
+# Translators: this represents an item on the screen that has
+# been set insensitive (or grayed out).
+#
+speechInsensitiveString = _("grayed")
+
+# Translators: this represents the state of a checkbox.  It is meant
+# to be spoken to the user.
+#
+speechCheckboxIndicators = [_("not checked"),
+                            _("checked"),
+                            _("partially checked")]
+
+# Translators: this represents the state of a radio button.  It is
+# meant to be spoken to the user.
+#
+speechRadioButtonIndicators = [C_("radiobutton", "not selected"),
+                               C_("radiobutton", "selected")]
+
+# Translators: this represents the state of a toggle button.  It is
+# meant to be spoken to the user.
+#
+speechToggleButtonIndicators = [_("not pressed"), _("pressed")]
+
+# Translators: this represents the state of a node in a tree.
+# 'expanded' means the children are showing.  'collapsed' means the
+# children are not showing.
+#
+speechExpansionIndicators = [_("collapsed"), _("expanded")]
+
+# Translators: "multi-select" refers to a web form list
+# in which more than one item can be selected at a time.
+#
+speechMultiSelectString = _("multi-select")
+
+# Translators: this represents the depth of a node in a tree
+# view (i.e., how many ancestors a node has).  It is meant to be
+# spoken.
+#
+speechNodeLevelString = _("tree level %d")
+
+# Translators: this represents a list item in a document.
+# The nesting level is how 'deep' the item is (e.g., a
+# level of 2 represents a list item inside a list that's
+# inside another list). This is meant to be spoken.
+#
+speechNestingLevelString = _("Nesting level %d")
+
+# string to indicate end of printed line for braille displays:
+#
+disableBrailleEOL = False
+brailleEOLIndicator = " $l"
+
+# Translators: Certain objects (such as form controls on web pages)
+# can have STATE_REQUIRED set on them to inform the user that this
+# field must be filled out. This string is the default string which
+# will be spoken and displayed in braille to indicate this state is
+# present.
+#
+brailleRequiredStateString = _("required")
+
+# Translators: this is used to indicate the user is in a text
+# area that is not editable.  It is meant to be a short abbreviation
+# to be presented on the braille display.
+#
+brailleReadOnlyString = C_("text", "rdonly")
+
+# Translators: this represents an item on the screen that has
+# been set insensitive (or grayed out).
+#
+brailleInsensitiveString = _("grayed")
+
+# Strings used to indicate checkbox/radio button states in braille:
+#
+brailleCheckBoxIndicators = ["< >", "<x>", "<->"]
+brailleRadioButtonIndicators = ["& y", "&=y"]
+brailleToggleButtonIndicators = ["& y", "&=y"]
+
+# Translators: this represents the state of a node in a tree.
+# 'expanded' means the children are showing.  'collapsed' means the
+# children are not showing.
+#
+brailleExpansionIndicators = [_("collapsed"), _("expanded")]
+
+# Translators: this represents the depth of a node in a tree
+# view (i.e., how many ancestors a node has).  It is meant to
+# be presented on a braille display.
+#
+brailleNodeLevelString = _("TREE LEVEL %d")
+
+# Translators: this represents a list item in a document.
+# The nesting level is how 'deep' the item is (e.g., a
+# level of 2 represents a list item inside a list that's
+# inside another list).  It is meant to be presented on
+# the braille display.
+#
+brailleNestingLevelString = _("LEVEL %d")
+
+# String for delimiters between table cells
+#
+brailleTableCellDelimiter = " "
+
+# This is for bug #585417 - Allow pauses to be inserted into speech
+# output. We're keeping it separate for now until we get the pauses
+# sorted out just right.
+#
+useExperimentalSpeechProsody = True
+
+# If True, whenever a 'pause' keyword is found in a speech formatting
+# string, any string being created will be sent to the speech synthesis
+# system immediately.  This is for bug #585417 and allows for some
+# adaptation to how different systems handle queued speech.  For example,
+# some introduce unnaturally long pauses between requests to speak.
+#
+enablePauseBreaks = True
